@echo off
setlocal

rem
rem This batch file expects 2 environment variables referenced at the top of this file.
rem 
rem 	RTSDK_JAVA_HOME  - root directory of your Refinitiv Real-Time SDK for java
rem		JAVA_HOME			- root directory of your Java environment
rem
rem Alternatively, you can modify these references with your own hard-coded specification or environment variable
rem
rem In addition, the RTSDK releases are versioned within Maven and release packages will use this version number
rem within library file names.  Set the version of your RTSDK installation.

rem RTSDK Version
set VERSION=3.6.2.0

rem Refinitiv Real-Time SDK folders
set ETAJ_HOME="%RTSDK_JAVA_HOME%"\Java\Eta
set EMAJ_HOME="%RTSDK_JAVA_HOME%"\Java\Ema

rem Java runtime (use -Xdiag to determine class loading issues)
set JAVA="%JAVA_HOME%\bin\java"

set BINPAK="%RTSDK_JAVA_HOME%"\RTSDK-BinaryPack\Java


set SCRIPT=%0

set CLASSPATH=.;.\bin;%EMAJ_HOME%\Libs\ema-%VERSION%.jar;%ETAJ_HOME%\Libs\eta-%VERSION%.jar;%ETAJ_HOME%\Libs\etaValueAdd-%VERSION%.jar;%ETAJ_HOME%\Libs\etajConverter-%VERSION%.jar;%BINPAK%\Ema\Libs\apache\commons-collections-3.2.2.jar;%BINPAK%\Ema\Libs\apache\commons-configuration-1.10.jar;%BINPAK%\Ema\Libs\apache\commons-lang-2.6.jar;%BINPAK%\Ema\Libs\apache\commons-logging-1.2.jar;%BINPAK%\Eta\Libs\SLF4J\slf4j-1.7.12\slf4j-api-1.7.12.jar;%BINPAK%\Eta\Libs\SLF4J\slf4j-1.7.12\slf4j-jdk14-1.7.12.jar;%BINPAK%\Eta\Libs\ApacheClient\httpcore-4.4.13.jar;%BINPAK%\Eta\Libs\ApacheClient\httpcore-nio-4.4.12.jar;%BINPAK%\Eta\Libs\ApacheClient\httpclient-4.5.13.jar;%BINPAK%\Eta\Libs\json-20180130.jar;%BINPAK%\Eta\Libs\jackson-core-2.11.0.jar;%BINPAK%\Eta\Libs\jackson-databind-2.11.0.jar;%BINPAK%\Eta\Libs\lz4-java-1.7.1.jar


: Check if a tutorial number is not provided
if "%1"=="" goto :NO_TUTORIAL

rem Collect the command-line parameters
for /f "tokens=1*" %%a in ("%*") do (
    
    set tutorial=%%a
    set args=%%b
)

if %tutorial%==1 goto :1
if %tutorial%==2 goto :2
if %tutorial%==3 goto :3
if %tutorial%==4 goto :4
if %tutorial%==5 goto :5
goto :Default

:1
echo Running tutorial 1...
%JAVA% -cp %CLASSPATH% com.refinitiv.ema.tutorials.consumer.tutorial1.basicConsumer
goto :EOF

:2
echo Running tutorial 2...
%JAVA% -cp %CLASSPATH% com.refinitiv.ema.tutorials.consumer.tutorial2.basicConsumer %args%
goto :EOF

:3
echo Running tutorial 3...
%JAVA% -cp %CLASSPATH% com.refinitiv.ema.tutorials.consumer.tutorial3.basicConsumer %args%
goto :EOF

:4
echo Running tutorial 4...
%JAVA% -cp %CLASSPATH% com.refinitiv.ema.tutorials.consumer.tutorial4.basicConsumer %args%
goto :EOF

:5
echo Running tutorial 5...
%JAVA% -cp %CLASSPATH% com.refinitiv.ema.tutorials.consumer.tutorial5.basicConsumer %args%
goto :EOF


:Default
echo Invalid tutorial specified
goto :NO_TUTORIAL


:NO_TUTORIAL
echo.
echo ======================================================================
echo Which tutorial do you want to run?  Valid tutorials: 1, 2, 3, 4, 5
echo Eg: %SCRIPT% 1
echo ======================================================================
