/*
	Commopn - Common functionality across all tutorials

 */

package com.refinitiv.ema.tutorials.consumer;

import java.util.List;

import com.refinitiv.ema.access.EmaFactory;
import com.refinitiv.ema.access.ElementList;
import com.refinitiv.ema.access.Map;
import com.refinitiv.ema.access.MapEntry;
import com.refinitiv.ema.access.OmmConsumerConfig;
import com.refinitiv.ema.access.ServiceEndpointDiscovery;
import com.refinitiv.ema.access.ServiceEndpointDiscoveryClient;
import com.refinitiv.ema.access.ServiceEndpointDiscoveryEvent;
import com.refinitiv.ema.access.ServiceEndpointDiscoveryOption;
import com.refinitiv.ema.access.ServiceEndpointDiscoveryResp;
import com.refinitiv.ema.access.OmmException;

public class Common implements ServiceEndpointDiscoveryClient
{
    public static String userName;
	public static String password;
	public static String clientId;
    public static String location = "us-east";
	
    public static String host;
	public static String itemName = "IBM.N";
    public static String service = "ELEKTRON_DD";
    
    static String endpointUrl;
    static String endpointPort;
    
    static public boolean readCommandlineArgs(String[] args, OmmConsumerConfig config)
	{
	    try
	    {
	        int argsCount = 0;

	        while (argsCount < args.length)
	        {
	            if (0 == args[argsCount].compareTo("-?"))
	            {
	                printHelp();
	                return false;
	            }
	            else if ("-username".equals(args[argsCount]))
    			{
	            	userName = argsCount < (args.length-1) ? args[++argsCount] : null;
    				++argsCount;				
    			}
	            else if ("-password".equals(args[argsCount]))
    			{
	            	password = argsCount < (args.length-1) ? args[++argsCount] : null;
    				++argsCount;				
    			}
	            else if ("-clientId".equals(args[argsCount]))
    			{
	            	clientId = argsCount < (args.length-1) ? args[++argsCount] : null;
    				++argsCount;				
    			}
	            else if ("-location".equals(args[argsCount]))
    			{
	            	location = argsCount < (args.length-1) ? args[++argsCount] : null;
    				++argsCount;				
    			}
    			else if ("-itemName".equals(args[argsCount]))
    			{
    				itemName = argsCount < (args.length-1) ? args[++argsCount] : null;
    				++argsCount;
    			}
    			else if ("-host".equals(args[argsCount]))
    			{
    				host = argsCount < (args.length-1) ? args[++argsCount] : null;
    				++argsCount;
    			}
    			else if ("-service".equals(args[argsCount]))
    			{
    				service = argsCount < (args.length-1) ? args[++argsCount] : null;
    				++argsCount;
    			}                
    			else // unrecognized command line argument
    			{
                    System.out.println("\nUnrecognized argument: " + args[argsCount]);
    				printHelp();
    				return false;
    			}			
    		}
	        
	        if ( args.length == 0 || host == null && (userName == null || password == null || clientId == null))
			{
				System.out.println("\nMissing required parameters.");
				printHelp();
				return false;
			}
        }
        catch (Exception e)
        {
            System.out.println("\nException:" + e.getMessage());
        	printHelp();
            return false;
        }
		
		return true;
	}
    
    static void printHelp()
	{
	    System.out.println("\nOptions (Connecting into Real-Time -- Optimized):\n"
	    		+ "  -username\tMachine ID to perform authorization with the token service. Required. [" + userName + "]\n"
	    		+ "  -password\tPassword to perform authorization with the token service. Required. [" + password + "]\n"
	    		+ "  -clientId\tClient ID, or Appkey. Required. [" + clientId + "]\n"
	    		+ "  -location\tLocation to get an endpoint from RDP service discovery. Default: [" + location + "]\n"
                + "  -service\tName of service providing market data. Default: [" + service + "]\n"                
	    		+ "  -itemName\tRequest item name. Default: [" + itemName + "]\n");
                
	    System.out.println("Options (Connecting into a deployed RTDS):\n"
	    		+ "  -host \tHostname or IP address and port of the deployed server (Eg: ads:14002). Required. [" + host + "]\n"
	    		+ "  -username\tUsername to connect into the deployed streaming server. [" + userName + "]\n"
                + "  -service\tName of service providing market data. Default: [" + service + "]\n"
	    		+ "  -itemName\tRequest item name. Default: [" + itemName + "]\n");
	}
    
    static public boolean createProgramaticConfig(Map configDb)
	{
        // Step1 - discover out streaming services within the cloud
        if ( !DiscoverStreamingServices() ) return false;
        
        // Based on the discovery, prepare the configuration to connect to Real-Time -- Optimized
		Map elementMap = EmaFactory.createMap();
		ElementList elementList = EmaFactory.createElementList();
		ElementList innerElementList = EmaFactory.createElementList();
		
		innerElementList.add(EmaFactory.createElementEntry().ascii("Channel", "Channel_1"));
		elementMap.add(EmaFactory.createMapEntry().keyAscii("Consumer_1", MapEntry.MapAction.ADD, innerElementList));
		innerElementList.clear();
		
		elementList.add(EmaFactory.createElementEntry().map("ConsumerList", elementMap));
		elementMap.clear();
		
		configDb.add(EmaFactory.createMapEntry().keyAscii("ConsumerGroup", MapEntry.MapAction.ADD, elementList));
		elementList.clear();
		
		innerElementList.add(EmaFactory.createElementEntry().ascii("ChannelType", "ChannelType::RSSL_ENCRYPTED"));
		innerElementList.add(EmaFactory.createElementEntry().ascii("Host", endpointUrl));
		innerElementList.add(EmaFactory.createElementEntry().ascii("Port", endpointPort));
		innerElementList.add(EmaFactory.createElementEntry().intValue("EnableSessionManagement", 1));
		
		elementMap.add(EmaFactory.createMapEntry().keyAscii("Channel_1", MapEntry.MapAction.ADD, innerElementList));
		innerElementList.clear();
		
		elementList.add(EmaFactory.createElementEntry().map("ChannelList", elementMap));
		elementMap.clear();
		
		configDb.add(EmaFactory.createMapEntry().keyAscii("ChannelGroup", MapEntry.MapAction.ADD, elementList));
		elementList.clear();
        
        return true;
	}
    
    static boolean DiscoverStreamingServices()
    {
        ServiceEndpointDiscovery serviceDiscovery = null;
		try
		{
			Common appClient = new Common();
			serviceDiscovery = EmaFactory.createServiceEndpointDiscovery();
			
			serviceDiscovery.registerClient(EmaFactory.createServiceEndpointDiscoveryOption()
                    .username(userName)
					.password(password)
                    .clientId(clientId), appClient);
                    
            serviceDiscovery.uninitialize();
        }
		catch (OmmException excp)
		{
			System.out.println("Stream Discovery Exception: " + excp);
		}  

        return endpointUrl != null;
    }
    
    public void onSuccess(ServiceEndpointDiscoveryResp serviceEndpointResp, ServiceEndpointDiscoveryEvent event)
	{
		System.out.println(serviceEndpointResp);
		
		for(int index = 0; index < serviceEndpointResp.serviceEndpointInfoList().size(); index++)
		{
			List<String> locationList = serviceEndpointResp.serviceEndpointInfoList().get(index).locationList();
			
			if(locationList.size() == 2) // Get an endpoint that provides auto failover for the specified location.
			{
				if(locationList.get(0).startsWith(location))
				{
					endpointUrl = serviceEndpointResp.serviceEndpointInfoList().get(index).endpoint();
					endpointPort = serviceEndpointResp.serviceEndpointInfoList().get(index).port();
                    
                    System.out.println("Based on the location: [" + location + "] selected: [" + endpointUrl + ":" + endpointPort + "]");
					break;
				}
			}
		}
	}
    
    public void onError(String errorText, ServiceEndpointDiscoveryEvent event)
	{
		System.out.println("Failed to query RDP service discovery. Error text: " + errorText);
	}
}